/* The copyright in this software is being made available under the BSD
 * License, included below. This software may be subject to other third party
 * and contributor rights, including patent rights, and no such rights are
 * granted under this license.  
 *
 * Copyright (c) 2010-2011, ITU/ISO/IEC
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  * Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  * Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *  * Neither the name of the ITU/ISO/IEC nor the names of its contributors may
 *    be used to endorse or promote products derived from this software without
 *    specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

/** \file     decmain.cpp
    \brief    Decoder application main
*/

#include <stdlib.h>
#include <stdio.h>
#include <time.h>
#include "TAppDecTop.h"

#ifdef GET_TIME
#include <sys/time.h>
#include <sys/resource.h>

extern double DecEntTime;
extern double DecBitTime;
extern double DecAllTime;
extern double DecCuTime;
extern double DecEPTime;
extern double DecMultiEPTime;
#endif //GET_TIME

bool g_md5_mismatch = false; ///< top level flag that indicates if there has been a decoding mismatch

// ====================================================================================================================
// Main function
// ====================================================================================================================

int main(int argc, char* argv[])
{
  TAppDecTop  cTAppDecTop;

  // print information
  fprintf( stdout, "\n" );
  fprintf( stdout, "HM software: Decoder Version [%s]", NV_VERSION );
  fprintf( stdout, NVM_ONOS );
  fprintf( stdout, NVM_COMPILEDBY );
  fprintf( stdout, NVM_BITS );
  fprintf( stdout, "\n" );

  // create application decoder class
  cTAppDecTop.create();

  // parse configuration
  if(!cTAppDecTop.parseCfg( argc, argv ))
  {
    cTAppDecTop.destroy();
    return 1;
  }

  // starting time
  double dResult;
  long lBefore = clock();

#ifdef GET_TIME_WHOLE
  struct rusage t1, t2;
  getrusage(RUSAGE_SELF, &t1);
#endif //GET_TIME_WHOLE
  // call decoding function
  cTAppDecTop.decode();
#ifdef GET_TIME_WHOLE
  getrusage(RUSAGE_SELF, &t2);
  DecAllTime += t2.ru_utime.tv_sec + (double)t2.ru_utime.tv_usec*1e-6 - t1.ru_utime.tv_sec - (double)t1.ru_utime.tv_usec*1e-6;
  getrusage(RUSAGE_SELF, &t1);
  getrusage(RUSAGE_SELF, &t2);
  DecAllTime -= t2.ru_utime.tv_sec + (double)t2.ru_utime.tv_usec*1e-6 - t1.ru_utime.tv_sec - (double)t1.ru_utime.tv_usec*1e-6;
#endif //GET_TIME_WHOLE

#ifdef GET_TIME
  double FocusTime;
#ifdef GET_TIME_ENTROPY
  FocusTime = DecEntTime;
#endif //GET_TIME_ENTROPY

#ifdef GET_TIME_BIT
  FocusTime = DecBitTime;
#endif //GET_TIME_BIT

#ifdef GET_TIME_DECCU
  FocusTime = DecCuTime;
#endif //GET_TIME_DECCU

#ifdef GET_TIME_WHOLE
  FocusTime = DecAllTime;
#endif //GET_TIME_WHOLE

#ifdef GET_TIME_EP
  FocusTime = DecEPTime;
#endif //GET_TIME_EP

#ifdef GET_TIME_MULTIEP
  FocusTime = DecMultiEPTime;
#endif //GET_TIME_MULTIEP

#endif //GET_TIME

#ifdef GET_TIME
  printf("\ndecodeFocusTime:\t%f sec. \n", FocusTime);
#endif //GET_TIME

  if (g_md5_mismatch)
  {
    printf("\n\n***ERROR*** A decoding mismatch occured: signalled md5sum does not match\n");
  }

  // ending time
  dResult = (double)(clock()-lBefore) / CLOCKS_PER_SEC;
  printf("\n Total Time: %12.3f sec.\n", dResult);

  // destroy application decoder class
  cTAppDecTop.destroy();

  return g_md5_mismatch ? EXIT_FAILURE : EXIT_SUCCESS;
}


