/* ====================================================================================================================

  The copyright in this software is being made available under the License included below.
  This software may be subject to other third party and   contributor rights, including patent rights, and no such
  rights are granted under this license.

  Copyright (c) 2010, FRAUNHOFER HHI
  All rights reserved.

  Redistribution and use in source and binary forms, with or without modification, are permitted only for
  the purpose of developing standards within the Joint Collaborative Team on Video Coding and for testing and
  promoting such standards. The following conditions are required to be met:

    * Redistributions of source code must retain the above copyright notice, this list of conditions and
      the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright notice, this list of conditions and
      the following disclaimer in the documentation and/or other materials provided with the distribution.
    * The name of FRAUNHOFER HHI
      may be used to endorse or promote products derived from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
  INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
  SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
  ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 * ====================================================================================================================
*/

/** \file     TEncPIPETables.cpp
    \brief    PIPE encoding tables
*/

#include "TEncPIPETables.h"


#if PIPE_V2V_V2F
#ifdef PIPE_V2F_8BITS_TRMONLY
const UInt  TEncPIPETables::sm_MaxTableSize[NUM_V2V_CODERS] = 
{
   4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8
};

const UInt  TEncPIPETables::sm_CWFixLength[NUM_V2V_CODERS] = 
{
   4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  8
};

const UInt  TEncPIPETables::sm_State2Idx[64] =
{
   0,   0,   0,   1,       1,   1,   2,   2,
   2,   3,   3,   3,       4,   4,   5,   5,
   5,   5,   6,   7,       7,   8,   8,   9,
  10,  10,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11,
  12,  12,  12,  12,      12,  12,  12,  12,
  12,  12,  12,  12,      12,  12,  12,  12
};

const UChar TEncPIPETables::sm_StateTransition[NUM_V2V_CODERS][260] =
{
  {
       2,   1,  15,   0,       4,   3,  15,   0,       6,   5,  23,   0,       8,   7,  15,   0,
      10,   9,  19,   0,      12,  11,  23,   0,      14,  13,  27,   0,      16,  15,  15,   0,
      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  21,   0,      24,  23,  23,   0,
      26,  25,  25,   0,      28,  27,  27,   0,      30,  29,  29,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   7,   0,       4,   3,   7,   0,       6,   5,  21,   0,       8,   7,   7,   0,
      10,   9,  17,   0,      12,  11,  21,   0,      14,  13,  25,   0,       0,   0,   0,   0,
      16,  15,  15,   0,      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  21,   0,
      24,  23,  23,   0,      26,  25,  25,   0,      28,  27,  27,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   7,   0,       4,   3,   7,   0,       6,   5,  11,   0,       8,   7,   7,   0,
      10,   9,   9,   0,      12,  11,  11,   0,      14,  13,  19,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  25,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      24,  23,  23,   0,      26,  25,  25,   0,      28,  27,  27,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  23,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,       0,   0,   0,   0,      24,  23,  23,   0,
      26,  25,  25,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  19,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      22,  21,  21,   0,       0,   0,   0,   0,
      24,  23,  23,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  19,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  15,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      14,  13,  13,   0,      16,  15,  15,   0,
      18,  17,  17,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  11,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      14,  13,  13,   0,       0,   0,   0,   0,
      16,  15,  15,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  11,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   5,   0,       0,   0,   0,   0,
       8,   7,   7,   0,       0,   0,   0,   0,      10,   9,   9,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      12,  11,  11,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   5,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       8,   7,   7,   0,       0,   0,   0,   0,
      10,   9,   9,   0,       0,   0,   0,   0,      12,  11,  11,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       3,   2,   2,   0,       0,   0,   0,   0,       0,   0,   0,   0,       5,   4,   4,   0,
       0,   0,   0,   0,       7,   6,   6,   0,       0,   0,   0,   0,       9,   8,   8,   0,
       0,   0,   0,   0,      11,  10,  10,   0,       0,   0,   0,   0,      13,  12,  12,   0,
       0,   0,   0,   0,      15,  14,  14,   0,       0,   0,   0,   0,      17,  16,  16,   0,
       0,   0,   0,   0,      19,  18,  18,   0,       0,   0,   0,   0,      21,  20,  20,   0,
       0,   0,   0,   0,      23,  22,  22,   0,       0,   0,   0,   0,      25,  24,  24,   0,
       0,   0,   0,   0,      27,  26,  26,   0,       0,   0,   0,   0,      29,  28,  28,   0,
       0,   0,   0,   0,      31,  30,  30,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  }
};

const UInt64 TEncPIPETables::sm_Codeword[NUM_V2V_CODERS][65] =
{
  {
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,     964,
         900,     836,     772,     708,     644,     580,     516,     452,     388,     324,     260,     196,     132,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,     964,       0,       0,       0,       0,       0,       0,       0,     900,
         836,     772,     708,     644,     580,     516,     452,     388,     324,     260,     196,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,     964,     900,     836,       0,     644,       0,       0,       0,     772,
         708,     580,     516,     452,       0,       0,       0,     388,     324,     260,     196,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
           0,     452,     388,       0,       0,     580,     516,     324,     260,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
         580,     516,       0,     324,       0,     452,     388,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
         580,     516,     452,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,       0,       0,       0,     708,     644,     580,
         516,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,       0,     580,       0,     708,     644,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,     708,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,     772,       0,     900,     836,     708,       0,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,     900,     836,       0,     772,       0,     708,       0,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,     964,       0,     900,       0,     836,       0,     772,       0,     708,       0,     644,       0,     580,       0,
         516,       0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  }
};


#else //PIPE_V2F_8BITS_TRMONLY
const UInt  TEncPIPETables::sm_MaxTableSize[NUM_V2V_CODERS] = 
{
   4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4
};

const UInt  TEncPIPETables::sm_CWFixLength[NUM_V2V_CODERS] = 
{
   4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4,  4
};

const UInt  TEncPIPETables::sm_State2Idx[64] =
{
   0,   0,   0,   1,       1,   1,   2,   2,
   2,   3,   3,   3,       4,   4,   5,   5,
   5,   5,   6,   7,       7,   8,   8,   9,
  10,  10,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11,
  11,  11,  11,  11,      11,  11,  11,  11
};

const UChar TEncPIPETables::sm_StateTransition[NUM_V2V_CODERS][260] =
{
  {
       2,   1,  15,   0,       4,   3,  15,   0,       6,   5,  23,   0,       8,   7,  15,   0,
      10,   9,  19,   0,      12,  11,  23,   0,      14,  13,  27,   0,      16,  15,  15,   0,
      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  21,   0,      24,  23,  23,   0,
      26,  25,  25,   0,      28,  27,  27,   0,      30,  29,  29,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   7,   0,       4,   3,   7,   0,       6,   5,  21,   0,       8,   7,   7,   0,
      10,   9,  17,   0,      12,  11,  21,   0,      14,  13,  25,   0,       0,   0,   0,   0,
      16,  15,  15,   0,      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  21,   0,
      24,  23,  23,   0,      26,  25,  25,   0,      28,  27,  27,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   7,   0,       4,   3,   7,   0,       6,   5,  11,   0,       8,   7,   7,   0,
      10,   9,   9,   0,      12,  11,  11,   0,      14,  13,  19,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,      20,  19,  19,   0,      22,  21,  25,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      24,  23,  23,   0,      26,  25,  25,   0,      28,  27,  27,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  23,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,       0,   0,   0,   0,      24,  23,  23,   0,
      26,  25,  25,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  19,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      22,  21,  21,   0,       0,   0,   0,   0,
      24,  23,  23,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  17,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,      18,  17,  17,   0,
      20,  19,  19,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  15,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      14,  13,  13,   0,      16,  15,  15,   0,
      18,  17,  17,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  11,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      14,  13,  13,   0,       0,   0,   0,   0,
      16,  15,  15,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   9,   0,       0,   0,   0,   0,
       8,   7,   7,   0,      10,   9,   9,   0,      12,  11,  11,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   5,   0,       0,   0,   0,   0,
       8,   7,   7,   0,       0,   0,   0,   0,      10,   9,   9,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      12,  11,  11,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   3,   0,       4,   3,   3,   0,       6,   5,   5,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       8,   7,   7,   0,       0,   0,   0,   0,
      10,   9,   9,   0,       0,   0,   0,   0,      12,  11,  11,   0,       0,   0,   0,   0,
      14,  13,  13,   0,       0,   0,   0,   0,      16,  15,  15,   0,       0,   0,   0,   0,
      18,  17,  17,   0,       0,   0,   0,   0,      20,  19,  19,   0,       0,   0,   0,   0,
      22,  21,  21,   0,       0,   0,   0,   0,      24,  23,  23,   0,       0,   0,   0,   0,
      26,  25,  25,   0,       0,   0,   0,   0,      28,  27,  27,   0,       0,   0,   0,   0,
      30,  29,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       3,   2,   2,   0,       0,   0,   0,   0,       0,   0,   0,   0,       5,   4,   4,   0,
       0,   0,   0,   0,       7,   6,   6,   0,       0,   0,   0,   0,       9,   8,   8,   0,
       0,   0,   0,   0,      11,  10,  10,   0,       0,   0,   0,   0,      13,  12,  12,   0,
       0,   0,   0,   0,      15,  14,  14,   0,       0,   0,   0,   0,      17,  16,  16,   0,
       0,   0,   0,   0,      19,  18,  18,   0,       0,   0,   0,   0,      21,  20,  20,   0,
       0,   0,   0,   0,      23,  22,  22,   0,       0,   0,   0,   0,      25,  24,  24,   0,
       0,   0,   0,   0,      27,  26,  26,   0,       0,   0,   0,   0,      29,  28,  28,   0,
       0,   0,   0,   0,      31,  30,  30,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  }
};

const UInt64 TEncPIPETables::sm_Codeword[NUM_V2V_CODERS][65] =
{
  {
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,     964,
         900,     836,     772,     708,     644,     580,     516,     452,     388,     324,     260,     196,     132,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,     964,       0,       0,       0,       0,       0,       0,       0,     900,
         836,     772,     708,     644,     580,     516,     452,     388,     324,     260,     196,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,     964,     900,     836,       0,     644,       0,       0,       0,     772,
         708,     580,     516,     452,       0,       0,       0,     388,     324,     260,     196,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
           0,     452,     388,       0,       0,     580,     516,     324,     260,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
         580,     516,       0,     324,       0,     452,     388,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,       0,     708,       0,       0,       0,     836,     772,     644,
         580,     516,     452,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,       0,       0,       0,     708,     644,     580,
         516,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,       0,     580,       0,     708,     644,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,       0,       0,     900,     836,     772,     708,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,       0,     772,       0,     900,     836,     708,       0,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,     964,     900,     836,       0,     772,       0,     708,       0,     644,       0,     580,       0,     516,
           0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,     964,       0,     900,       0,     836,       0,     772,       0,     708,       0,     644,       0,     580,       0,
         516,       0,     452,       0,     388,       0,     324,       0,     260,       0,     196,       0,     132,       0,      68,       4,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  }
};

#endif //PIPE_V2F_8BITS_TRMONLY
#else //PIPE_V2V_V2F
const UInt  TEncPIPETables::sm_MaxTableSize[NUM_V2V_CODERS] = 
{
   1,  8,  8, 11,    6,  6,  8, 10,    9,  8,  6,  6
};

const UInt  TEncPIPETables::sm_State2Idx[64] =
{
   0,   0,   1,   2,       2,   3,   3,   4,
   4,   4,   5,   5,       5,   6,   6,   6,
   6,   7,   7,   7,       7,   8,   8,   8,
   8,   8,   8,   8,       8,   9,   9,   9,
   9,   9,   9,   9,       9,   9,   9,   9,
  10,  10,  10,  10,      10,  10,  10,  10,
  10,  10,  10,  10,      10,  10,  10,  10,
  11,  11,  11,  11,      11,  11,  11,  11
};

const UChar TEncPIPETables::sm_StateTransition[NUM_V2V_CODERS][260] =
{
  {
       1,   2,   1,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       3,   1,   4,   0,       2,   7,   2,   0,       0,   0,   0,   0,       5,   4,   4,   0,
       0,   0,   0,   0,       9,   6,   6,   0,       0,   0,   0,   0,       8,  15,   8,   0,
       0,   0,   0,   0,      12,  10,  14,   0,      20,  11,  11,   0,       0,   0,   0,   0,
      13,  18,  14,   0,      14,  26,  14,   0,       0,   0,   0,   0,      16,  22,  17,   0,
      17,  33,  17,   0,       0,   0,   0,   0,      24,  19,  25,   0,       0,   0,   0,   0,
      28,  21,  29,   0,       0,   0,   0,   0,      35,  23,  23,   0,       0,   0,   0,   0,
      25,  30,  25,   0,       0,   0,   0,   0,      27,  32,  27,   0,       0,   0,   0,   0,
      29,  31,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,      37,  34,  38,   0,       0,   0,   0,   0,      39,  36,  40,   0,
       0,   0,   0,   0,      38,  41,  38,   0,       0,   0,   0,   0,      40,  42,  40,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       3,   1,   4,   0,       2,  10,   2,   0,       0,   0,   0,   0,       5,   4,   4,   0,
       0,   0,   0,   0,       7,   6,   6,   0,       0,   0,   0,   0,       8,  13,   9,   0,
       9,  19,   9,   0,       0,   0,   0,   0,      11,  15,  12,   0,      12,  24,  12,   0,
       0,   0,   0,   0,      17,  14,  18,   0,       0,   0,   0,   0,      21,  16,  22,   0,
       0,   0,   0,   0,      18,  23,  18,   0,       0,   0,   0,   0,      20,  29,  20,   0,
       0,   0,   0,   0,      22,  26,  22,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      27,  25,  28,   0,       0,   0,   0,   0,       0,   0,   0,   0,      28,  33,  28,   0,
       0,   0,   0,   0,      31,  30,  32,   0,       0,   0,   0,   0,      32,  35,  32,   0,
       0,   0,   0,   0,      34,  36,  34,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       3,   1,   4,   0,       2,   9,   2,   0,       0,   0,   0,   0,       5,   4,   4,   0,
       0,   0,   0,   0,       7,   6,   8,   0,       0,   0,   0,   0,       8,  13,   8,   0,
       0,   0,   0,   0,      11,  10,  12,   0,       0,   0,   0,   0,      12,  17,  12,   0,
       0,   0,   0,   0,      15,  14,  16,   0,       0,   0,   0,   0,      16,  21,  16,   0,
       0,   0,   0,   0,      19,  18,  20,   0,       0,   0,   0,   0,      20,  25,  20,   0,
       0,   0,   0,   0,      23,  22,  24,   0,       0,   0,   0,   0,      24,  29,  24,   0,
       0,   0,   0,   0,      27,  26,  28,   0,       0,   0,   0,   0,      28,  33,  28,   0,
       0,   0,   0,   0,      31,  30,  32,   0,       0,   0,   0,   0,      32,  37,  32,   0,
       0,   0,   0,   0,      35,  34,  36,   0,       0,   0,   0,   0,      36,  39,  36,   0,
       0,   0,   0,   0,      38,  40,  38,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,   6,   5,   0,       2,  15,   5,   0,       3,  19,   5,   0,       4,   8,   5,   0,
       5,  10,   5,   0,       0,   0,   0,   0,      11,   7,   7,   0,       0,   0,   0,   0,
       9,  24,   9,   0,       0,   0,   0,   0,       0,   0,   0,   0,      12,  22,  14,   0,
      13,  35,  14,   0,      14,  34,  14,   0,       0,   0,   0,   0,      16,  25,  18,   0,
      17,  32,  18,   0,      18,  31,  18,   0,       0,   0,   0,   0,      20,  28,  21,   0,
      21,  30,  21,   0,       0,   0,   0,   0,      23,  38,  23,   0,       0,   0,   0,   0,
       0,   0,   0,   0,      26,  37,  27,   0,      27,  39,  27,   0,       0,   0,   0,   0,
      29,  40,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      33,  41,  33,   0,       0,   0,   0,   0,       0,   0,   0,   0,      36,  42,  36,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,   7,   2,   0,       2,   3,   2,   0,       0,   0,   0,   0,       4,  12,   6,   0,
       5,  16,   6,   0,       6,  18,   6,   0,       0,   0,   0,   0,       8,  14,  11,   0,
       9,  13,  11,   0,      10,  20,  11,   0,      11,  19,  11,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      15,  22,  15,   0,       0,   0,   0,   0,
      17,  23,  17,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
      21,  24,  21,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       2,   1,   1,   0,       0,   0,   0,   0,       5,   3,  10,   0,       4,  21,   4,   0,
       0,   0,   0,   0,       6,  11,  10,   0,       7,  17,  10,   0,       8,  15,  10,   0,
       9,  20,  10,   0,      10,  23,  10,   0,       0,   0,   0,   0,      12,  25,  14,   0,
      13,  27,  14,   0,      14,  29,  14,   0,       0,   0,   0,   0,      16,  33,  16,   0,
       0,   0,   0,   0,      18,  28,  19,   0,      19,  31,  19,   0,       0,   0,   0,   0,
       0,   0,   0,   0,      22,  35,  22,   0,       0,   0,   0,   0,      24,  37,  24,   0,
       0,   0,   0,   0,      26,  36,  26,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,      30,  39,  30,   0,       0,   0,   0,   0,      32,  40,  32,   0,
       0,   0,   0,   0,      34,  41,  34,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,      38,  42,  38,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,   6,   3,   0,       2,   4,   3,   0,       3,   9,   3,   0,       0,   0,   0,   0,
       5,  13,   5,   0,       0,   0,   0,   0,       7,  10,   8,   0,       8,  15,   8,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      11,  20,  12,   0,      12,  23,  12,   0,
       0,   0,   0,   0,      14,  22,  14,   0,       0,   0,   0,   0,      16,  24,  19,   0,
      17,  27,  19,   0,      18,  25,  19,   0,      19,  26,  19,   0,       0,   0,   0,   0,
      21,  30,  21,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,      28,  31,  29,   0,
      29,  32,  29,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,   5,   4,   0,       2,   7,   4,   0,       3,  12,   4,   0,       4,   9,   4,   0,
       0,   0,   0,   0,       6,  23,   6,   0,       0,   0,   0,   0,       8,  20,   8,   0,
       0,   0,   0,   0,      10,  16,  11,   0,      11,  27,  11,   0,       0,   0,   0,   0,
      13,  18,  15,   0,      14,  17,  15,   0,      15,  30,  15,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,      19,  36,  19,   0,       0,   0,   0,   0,
      21,  34,  22,   0,      22,  37,  22,   0,       0,   0,   0,   0,      24,  33,  26,   0,
      25,  35,  26,   0,      26,  38,  26,   0,       0,   0,   0,   0,      28,  39,  29,   0,
      29,  41,  29,   0,       0,   0,   0,   0,      31,  40,  32,   0,      32,  42,  32,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,   9,   8,   0,       2,  12,   8,   0,       3,  14,   8,   0,       4,  16,   8,   0,
       5,  17,   8,   0,       6,  18,   8,   0,       7,  19,   8,   0,       8,  24,   8,   0,
       0,   0,   0,   0,      10,  29,  11,   0,      11,  31,  11,   0,       0,   0,   0,   0,
      13,  30,  13,   0,       0,   0,   0,   0,      15,  32,  15,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,      20,  33,  23,   0,
      21,  34,  23,   0,      22,  36,  23,   0,      23,  38,  23,   0,       0,   0,   0,   0,
      25,  35,  28,   0,      26,  37,  28,   0,      27,  39,  28,   0,      28,  40,  28,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,  18,  17,   0,       2,  19,  17,   0,       3,  20,  17,   0,       4,  21,  17,   0,
       5,  22,  17,   0,       6,  23,  17,   0,       7,  24,  17,   0,       8,  25,  17,   0,
       9,  26,  17,   0,      10,  27,  17,   0,      11,  28,  17,   0,      12,  29,  17,   0,
      13,  30,  17,   0,      14,  31,  17,   0,      15,  32,  17,   0,      16,  33,  17,   0,
      17,  34,  17,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  },
  {
       1,  64,  32,   0,       2,  63,  32,   0,       3,  62,  32,   0,       4,  61,  32,   0,
       5,  60,  32,   0,       6,  59,  32,   0,       7,  58,  32,   0,       8,  57,  32,   0,
       9,  56,  32,   0,      10,  55,  32,   0,      11,  54,  32,   0,      12,  53,  32,   0,
      13,  52,  32,   0,      14,  51,  32,   0,      15,  50,  32,   0,      16,  49,  32,   0,
      17,  48,  32,   0,      18,  47,  32,   0,      19,  46,  32,   0,      20,  45,  32,   0,
      21,  44,  32,   0,      22,  43,  32,   0,      23,  42,  32,   0,      24,  41,  32,   0,
      25,  40,  32,   0,      26,  39,  32,   0,      27,  38,  32,   0,      28,  37,  32,   0,
      29,  36,  32,   0,      30,  35,  32,   0,      31,  34,  32,   0,      32,  33,  32,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,       0,   0,   0,   0,
       0,   0,   0,   0
  }
};


const UInt64 TEncPIPETables::sm_Codeword[NUM_V2V_CODERS][65] =
{
  {
           0,       1,      65,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,     130,       0,     194,       0,     131,       0,     195,       0,       0,     325,       0,       0,     389,       0,
           0,     453,       0,     262,       0,     326,       0,     390,       0,     454,       0,     518,       0,     582,      71,     135,
         199,       0,     263,       0,     327,       0,     391,       0,     455,       8,      72,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,     130,       0,     194,       0,     195,       0,       0,     260,       0,       0,     324,       0,     197,       0,
         261,       0,     325,       0,     389,       0,     453,     134,       0,     198,     262,       0,     326,       0,      71,       0,
         135,       0,     199,       8,      72,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,     130,       0,     194,       0,     131,       0,     195,       0,     132,       0,     196,       0,     133,       0,
         197,       0,     134,       0,     198,       0,     135,       0,     199,       0,     136,       0,     200,       0,     137,       0,
         201,       0,      74,       0,     138,       0,     202,      11,      75,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,     387,       0,     451,       0,     388,     452,       0,       0,       0,     516,       0,
           0,       0,     580,       0,       0,     644,       0,     708,     133,       0,       0,     197,       0,     261,     325,     389,
           0,     453,     517,       0,     581,     645,     709,       6,      70,     134,     198,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,      65,       0,       0,       0,     196,       0,       0,       0,       0,     260,     324,     388,       0,     452,
           0,      69,     133,     197,       0,     261,     325,       6,      70,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,     194,       0,       0,     259,       0,       0,       0,       0,       0,     323,       0,       0,       0,     260,       0,
         324,       0,       0,     388,     452,       0,     197,       0,     261,       0,     325,     389,     453,       0,     134,       0,
         198,       0,     262,     326,     135,       0,     199,       8,      72,     136,     200,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,      65,       0,      67,       0,       0,     131,     195,       0,       0,     133,       0,     197,       0,
           0,       0,       0,     198,       0,     135,     199,     263,     327,      72,     136,       0,       0,     200,      73,      10,
          74,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,      65,       0,     131,       0,     195,       0,       0,     132,       0,       0,       0,     196,
         198,     262,       0,     326,       0,       0,     390,       0,       0,       0,     454,       0,       0,     263,       0,       0,
         327,     136,     200,     264,     328,     392,     456,       9,      73,     137,     201,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,       0,      65,       0,       0,     132,       0,     196,       0,     260,
         324,     388,     452,       0,       0,       0,       0,     133,       0,       0,       0,       0,     197,     263,     327,     391,
         455,       8,      72,     136,     200,     264,     328,     392,     456,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,      65,      69,     133,     197,     261,     325,     389,     453,     517,     581,     645,     709,     773,     837,     901,
         965,       6,      70,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0
  },
  {
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
           0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,       0,
          65,       6,      70,     134,     198,     262,     326,     390,     454,     518,     582,     646,     710,     774,     838,     902,
         966,    1030,    1094,    1158,    1222,    1286,    1350,    1414,    1478,    1542,    1606,    1670,    1734,    1798,    1862,    1926,
        1990
  }
};

#endif //PIPE_V2V_V2F
